HXTarget

Enum HXTarget 

pub enum HXTarget<'a> {
    This,
    Closest(&'a str),
    Find,
    Next,
    NextSelector(&'a str),
    Previous,
    PreviousSelector(&'a str),
}
The hx-target attribute allows you to target a different element for swapping than the one issuing the AJAX request.

Variants



This

Which indicates that the element that the hx-target attribute is on is the target.



Closest(&'a str)

closest which will find the closest ancestor element or itself, that matches the given CSS selector (e.g. closest tr will target the closest table row to the element).



Find

find which will find the first child descendant element that matches the given CSS selector.



Next

next which resolves to element.nextElementSibling



NextSelector(&'a str)

next which will scan the DOM forward for the first element that matches the given CSS selector. (e.g. next .error will target the closest following sibling element with error class)



Previous

previous which resolves to element.previousElementSibling



PreviousSelector(&'a str)

previous which will scan the DOM backwards for the first element that matches the given CSS selector. (e.g. previous .error will target the closest previous sibling with error class)