pub fn dc_range() -> HtmlElementExpand description
Creates a new Daisy range component: input().class("range").typ("range").
Range slider selects a value by sliding a handle
pub fn dc_range() -> HtmlElementCreates a new Daisy range component: input().class("range").typ("range").
Range slider selects a value by sliding a handle