pub fn dc_tabs() -> HtmlElementExpand description
Creates a new Daisy tabs component: div().class("tabs").
Tabs show a list of links in a tabbed format
pub fn dc_tabs() -> HtmlElementCreates a new Daisy tabs component: div().class("tabs").
Tabs show a list of links in a tabbed format