closest which will find the closest ancestor element or itself, that matches
the given CSS selector (e.g. closest tr will target the closest table row to the element).
next which will scan the DOM forward for the first element that matches the
given CSS selector. (e.g. next .error will target the closest following sibling element
with error class)
previous which will scan the DOM backwards for the first element that
matches the given CSS selector. (e.g. previous .error will target the closest previous
sibling with error class)